## Your Environment
Thank you for taking the time to report an issue.

To more efficiently resolve this issue, we'd like to know some basic information about your system and setup.

1) Your operating system:

2) Version of python you are running:
``` bash
python --version
```

3) How did you install twine? Did you use your operating system's package manager or pip or something else?

4) Version of twine you have installed (include complete output of):
``` bash
twine --version
```

5) Which package repository are you targeting?


If you're having issues uploading a specific package, you *must* include a copy of the following:
* The package's `PKG-INFO` file
* A redacted version of your `.pypirc` file (**REMOVE ALL USERNAMES & PASSWORDS BEFORE UPLOADING**)


## The Issue
Please describe the issue that you are experiencing.


## Steps to Reproduce
If the issue is predictable and consistently reproducible, please list the steps here.



